@@ -270,27 +270,30 @@ void ADBSTB5::populateProtocol(
   addKey("8", Eight_Key, 0x08, 8);
   addKey("9", Nine_Key, 0x09, 8);
   addKey("Menu", Menu_Key, 0x0A, 8);
-  addKey("Guide", Guide_Key, 0x0B, 8);
+//  addKey("Guide", Guide_Key, 0x0B, 8);
   addKey("Power", Power_Key, 0x0C, 8);
   addKey("Format 16:9", AspectRatio_Key, 0x0D, 8);
   addKey("Info/Display", Info_Key, 0x0D, 8);
-  addKey("Stop", Stop_Key, 0x0D, 8);
+//  addKey("Stop", Stop_Key, 0x0D, 8);
   addKey("CH+", ChannelUp_Key, 0x0E, 8);
   addKey("CH-", ChannelDown_Key, 0xF, 8);
   addKey("Volume +", VolumeUp_Key, 0x10, 8);
   addKey("Volume -", VolumeDown_Key, 0x11, 8);
   addKey("Arrow_Right", Right_Key, 0x12, 8);
-  addKey("FFWD", FastForward_Key, 0x13, 8);
+//  addKey("FFWD", FastForward_Key, 0x13, 8);
+  addKey("Guide", Guide_Key, 0x13, 8);
   addKey("EXIT", Exit_Key, 0x14, 8);
   addKey("Arrow_Left", Left_Key, 0x15, 8);
   addKey("OK/Select", Select_Key, 0x16, 8);
   addKey("Subtitle", Captions_Key, 0x18, 8);
+  addKey("TV/RAD", TunerInput_Key, 0x19, 8);
   addKey("Mute", Mute_Key, 0x1A, 8);
   addKey("Input/Source", Input_Key, 0x1B, 8);
   addKey("Arrow_Down", Down_Key, 0x1C, 8);
   addKey("Arrow_Up", Up_Key, 0x1D, 8);
-  addKey("Play", Play_Key, 0x1E, 8);
-  addKey("Audio", Audio_Key, 0x1F, 8);
+//  addKey("Play", Play_Key, 0x1E, 8);
+//  addKey("Audio", Audio_Key, 0x1F, 8);
+  addKey("Back", PrevChannel_Key, 0x1F, 8);
   addKey("Red", Red_Key, 0x20, 8);
   addKey("Green", Green_Key, 0x21, 8);
   addKey("Yellow", Yellow_Key, 0x22, 8);
