@@ -15,4 +15,14 @@ public:
     QObject *guiObject);
 };
 
+class LogitechSqueezebox: public PIRKeysetMetaData
+{
+public:
+  LogitechSqueezebox(
+    unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
+};
+
 #endif // LOGITECH_H
