@@ -21,6 +21,7 @@ enum PIRMakeName{
   Bush_Make,
   Cambridge_Make,
   Canon_Make,
+  Changhong_Make,
   Cisco_Make,
   Compro_Make,
   Creative_Make,
@@ -43,6 +44,7 @@ enum PIRMakeName{
   Epson_Make,
   Fortec_Make,
   Foxtel_Make,
+  Frontech_Make,
   Gadmei_Make,
   Genius_Make,
   GoldStar_Make,
@@ -100,6 +102,7 @@ enum PIRMakeName{
   Samsung_Make,
   Sanyo_Make,
   Sharp_Make,
+  Sinotec_Make,
   Sky_Make,
   Sony_Make,
   Starsat_Make,
